use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::EOL 0.19

use Test::More 0.88;
use Test::EOL;

my @files = (
    'bin/envdot',
    'lib/Env/Dot.pm',
    'lib/Env/Dot/Functions.pm',
    'lib/Env/Dot/ScriptFunctions.pm',
    't/env-dot-functions-private.t',
    't/env-dot-functions-public-unix.t',
    't/env-dot-functions-public-win32.t',
    't/env-dot-functions-public.t',
    't/env-dot-override-example-synopsis.sh',
    't/env-dot-override-example-synopsis.t',
    't/env-dot-scriptfunctions.t',
    't/envdot-script-first.env',
    't/envdot-script-second.env',
    't/envdot-script-third.env',
    't/envdot-script.t',
    't/file-read-order/ENVDOT_FILEPATHS.t',
    't/file-read-order/dummy.env-first',
    't/file-read-order/dummy.env-interpolation',
    't/file-read-order/dummy.env-second',
    't/file-read-order/dummy.env-static',
    't/file-read-order/dummy.env-third',
    't/lib/Env/Dot/Test/Utils.pm',
    't/lib/Test2/Deny/Platform/DOSOrDerivative.pm',
    't/lib/Test2/Require/Platform/DOSOrDerivative.pm',
    't/lib/Test2/Require/Platform/Unix.pm',
    't/other/read-from-this-deeper-file.t',
    't/other/read-from-this-file.t',
    't/recursive-read.t',
    't/required-dotenv/by-default-no-envdot-present/.test-script-0mxb6OuZ/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default-no-envdot-present/.test-script-1YvQHfoj/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default-no-envdot-present/.test-script-24dP2mn2/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default-no-envdot-present/.test-script-2i4c1YvQ/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default-no-envdot-present/.test-script-3MaDBusy/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default-no-envdot-present/.test-script-6OuZz9ir/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default-no-envdot-present/.test-script-7YuCGkkz/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default-no-envdot-present/.test-script-GY47K9VG/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default-no-envdot-present/.test-script-K9VGFliO/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default-no-envdot-present/.test-script-OkdRtZc7/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default-no-envdot-present/.test-script-VI85GY47/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default-no-envdot-present/.test-script-ZyZy_FBI/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default-no-envdot-present/.test-script-_FBI2i4c/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default-no-envdot-present/.test-script-_niQ6N3q/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default-no-envdot-present/.test-script-hDs8tpfN/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default-no-envdot-present/.test-script-hcaUPT1y/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default-no-envdot-present/.test-script-jatvsg5A/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default-no-envdot-present/.test-script-m7RMcCGr/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default-no-envdot-present/.test-script-peOFVI85/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default-no-envdot-present/.test-script-scB2VLHB/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default-no-envdot-present/.test-script-xNyVoDmS/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default-no-envdot-present/.test-script-yf9mGAek/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default-no-envdot-present/.test-script-z9irpeOF/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default-no-envdot-present/prg.pl',
    't/required-dotenv/by-default/.env',
    't/required-dotenv/by-default/.test-script-0DiaLci4/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default/.test-script-2i4c1YvQ/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default/.test-script-2mn27YuC/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default/.test-script-2pUVDZcW/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default/.test-script-5v2H1arA/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default/.test-script-7kJU1qZz/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default/.test-script-GkkzMJzC/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default/.test-script-Hfojm7RM/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default/.test-script-I1Vp24dP/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default/.test-script-LsKItM1l/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default/.test-script-QfIl2mp9/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default/.test-script-SJwCml_i/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default/.test-script-Usvp4tnn/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default/.test-script-UwFIJUPI/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default/.test-script-WNE_8xXJ/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default/.test-script-ZyZy_FBI/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default/.test-script-hcaUPT1y/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default/.test-script-jatvsg5A/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default/.test-script-p2IkDJIW/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default/.test-script-piw9otEH/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default/.test-script-sYUGdGbs/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default/.test-script-tcKoYfx2/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default/.test-script-xzpoE6Rq/__TEST_SCRIPT__.pm',
    't/required-dotenv/by-default/prg.pl',
    't/required-dotenv/required-dotenv.t',
    't/required-dotenv/specifically-not-required-no-envdot-present/.test-script-3MaDBusy/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required-no-envdot-present/.test-script-5PylwydS/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required-no-envdot-present/.test-script-6N3q0mxb/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required-no-envdot-present/.test-script-6OuZz9ir/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required-no-envdot-present/.test-script-BusyOkdR/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required-no-envdot-present/.test-script-FliO3MaD/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required-no-envdot-present/.test-script-GAekscB2/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required-no-envdot-present/.test-script-GY47K9VG/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required-no-envdot-present/.test-script-Lci4Usvp/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required-no-envdot-present/.test-script-OkdRtZc7/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required-no-envdot-present/.test-script-QfIl2mp9/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required-no-envdot-present/.test-script-VLHB_niQ/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required-no-envdot-present/.test-script-ZyZy_FBI/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required-no-envdot-present/.test-script-el_Ov2g6/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required-no-envdot-present/.test-script-hDs8tpfN/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required-no-envdot-present/.test-script-oDmSVUtb/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required-no-envdot-present/.test-script-otEH0Dia/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required-no-envdot-present/.test-script-peOFVI85/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required-no-envdot-present/.test-script-scB2VLHB/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required-no-envdot-present/.test-script-tZc7hDs8/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required-no-envdot-present/.test-script-tpfNxNyV/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required-no-envdot-present/.test-script-yYSiuntu/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required-no-envdot-present/.test-script-yf9mGAek/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required-no-envdot-present/prg.pl',
    't/required-dotenv/specifically-not-required/.env',
    't/required-dotenv/specifically-not-required/.test-script-1YvQHfoj/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required/.test-script-1qZzp2Ik/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required/.test-script-24dP2mn2/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required/.test-script-2i4c1YvQ/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required/.test-script-2mp9ZyZy/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required/.test-script-4tnntcKo/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required/.test-script-7YuCGkkz/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required/.test-script-8xXJ2pUV/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required/.test-script-DJIWSJwC/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required/.test-script-DZcWI1Vp/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required/.test-script-Hfojm7RM/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required/.test-script-JUPIQfIl/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required/.test-script-Lci4Usvp/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required/.test-script-Yfx2xzpo/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required/.test-script-ZyZy_FBI/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required/.test-script-_FBI2i4c/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required/.test-script-_niQ6N3q/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required/.test-script-m7RMcCGr/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required/.test-script-ml_i5v2H/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required/.test-script-otEH0Dia/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required/.test-script-scB2VLHB/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required/.test-script-tM1l7kJU/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required/.test-script-yf9mGAek/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-not-required/prg.pl',
    't/required-dotenv/specifically-required-no-envdot-present/.test-script-3MaDBusy/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required-no-envdot-present/.test-script-6OuZz9ir/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required-no-envdot-present/.test-script-7aLrARRH/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required-no-envdot-present/.test-script-D34jJLwk/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required-no-envdot-present/.test-script-K9VGFliO/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required-no-envdot-present/.test-script-Lci4Usvp/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required-no-envdot-present/.test-script-OkdRtZc7/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required-no-envdot-present/.test-script-VI85GY47/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required-no-envdot-present/.test-script-VUtbel_O/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required-no-envdot-present/.test-script-el_Ov2g6/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required-no-envdot-present/.test-script-hDs8tpfN/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required-no-envdot-present/.test-script-oDmSVUtb/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required-no-envdot-present/.test-script-otEH0Dia/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required-no-envdot-present/.test-script-peOFVI85/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required-no-envdot-present/.test-script-tqsI_YtN/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required-no-envdot-present/.test-script-untu5Pyl/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required-no-envdot-present/.test-script-v2g6yYSi/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required-no-envdot-present/.test-script-wydS_zFG/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required-no-envdot-present/.test-script-xNyVoDmS/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required-no-envdot-present/.test-script-yYSiuntu/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required-no-envdot-present/.test-script-yf9mGAek/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required-no-envdot-present/.test-script-z9irpeOF/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required-no-envdot-present/prg.pl',
    't/required-dotenv/specifically-required/.env',
    't/required-dotenv/specifically-required/.test-script-2i4c1YvQ/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required/.test-script-2pUVDZcW/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required/.test-script-5v2H1arA/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required/.test-script-6N3q0mxb/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required/.test-script-6OuZz9ir/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required/.test-script-7kJU1qZz/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required/.test-script-FliO3MaD/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required/.test-script-GAekscB2/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required/.test-script-GY47K9VG/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required/.test-script-GkkzMJzC/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required/.test-script-Hfojm7RM/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required/.test-script-Lci4Usvp/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required/.test-script-QfIl2mp9/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required/.test-script-UwFIJUPI/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required/.test-script-VLHB_niQ/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required/.test-script-WNE_8xXJ/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required/.test-script-ZyZy_FBI/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required/.test-script-_niQ6N3q/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required/.test-script-cCGryf9m/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required/.test-script-otEH0Dia/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required/.test-script-peOFVI85/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required/.test-script-scB2VLHB/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required/.test-script-yf9mGAek/__TEST_SCRIPT__.pm',
    't/required-dotenv/specifically-required/prg.pl'
);

eol_unix_ok($_, { trailing_whitespace => 1 }) foreach @files;
done_testing;
