use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007006
use Test::Spelling 0.17;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( lib bin script ) );
__DATA__
David
Dot
Env
Functions
Kaufman
Koivunalho
Mikko
ScriptFunctions
Sven
Twata
Willenbuecher
bin
david
dotenv
env
envdot
gregoa
gregor
herrmann
lib
mikkoi
sven
twata_1
